parse_plugin_action_invoke_request

Function parse_plugin_action_invoke_request 

pub fn parse_plugin_action_invoke_request(
    input: impl Read,
    expected_plugin_id: Uuid,
    allowed_action_ids: &[&str],
) -> Result<PluginActionInvokeRequest>
Parses the bounded JSON request received by a plugin in invoke mode.

allowed_action_ids must contain the plugin’s complete set of at most PLUGIN_ACTION_LIMIT unique, valid action IDs. This prevents a validly shaped request from dispatching an undeclared action.