pub fn parse_plugin_action_probe(
manifest: &PluginManifest,
contribution: &PluginActionContribution,
output: &PluginOutput,
) -> Result<Vec<PluginActionMetadata>>Expand description
Parses and validates a completed action probe without trusting plugin IDs, action identifiers, menu placement, or selection matchers from stdout.