spawn_plugin_action

Function spawn_plugin_action 

pub fn spawn_plugin_action(
    manifest: &PluginManifest,
    contribution: &PluginActionContribution,
    action: &PluginActionMetadata,
    context: &PluginActionContext,
) -> Result<PluginProcess>
Starts an action previously returned by a validated probe. Invocation is rejected when the action no longer matches the supplied context.